@@ -32,20 +32,16 @@
 #include "updated.h"
 #include "label.h"
 #include "button.h"
+#include "text.h"
 
 GtkWidget      *gsh_window;
-GtkWidget      *gsh_button;
 GtkWidget      *gsh_hbox;
 GtkWidget      *gsh_vbox;
 GtkWidget      *gsh_label;
 
-void
-gsh_command_button(char *command);
 
 void
 gsh_manage(GtkWidget *widget);
 
-void
-gsh_image_button(char *command, char *filename);
 
 #endif
