@@ -36,11 +36,18 @@ gsh_setup_containers()
 int
 main(int argc, char **argv)
 {
- gtk_init(&argc, &argv);
- gsh_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
- gsh_setup_containers();
- gsh_handle_arguments(argc, argv);
- gtk_widget_show(gsh_window);
- gtk_main();
- return (0);
+ 	gtk_init(&argc, &argv);
+
+ 	gsh_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+	g_signal_connect (gsh_window, "delete-event",
+		G_CALLBACK (gtk_main_quit), NULL);
+  	g_signal_connect (gsh_window, "destroy",
+		G_CALLBACK (gtk_main_quit), NULL); 
+	gsh_setup_containers();
+ 	gsh_handle_arguments(argc, argv);
+ 	gtk_widget_show(gsh_window);
+	
+ 	gtk_main();
+
+	return (0);
 }
