@@ -19,9 +19,36 @@
   along with AntiRight; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
+
 #ifndef GSH_UPDATED_H
 #define GSH_UPDATED_H
 
+struct gsh_updated_struct
+{
+	void *next;
+	void (*function)(char *, void *);
+	char *command;
+	void *widget;
+};
+
 void
-                gsh_dynamic_label(char *command);
+gsh_add_to_updates(struct gsh_updated_struct *update);
+
+void
+gsh_add_update(void (*function)(char *, void *),
+        char *command, void *widget);
+
+void    
+gsh_update_label(char *command, void *widget);
+
+void    
+gsh_add_updated_label(char *command);
+
+void    
+gsh_start_updates();
+
+gint
+gsh_perform_updates(gpointer data);
+
 #endif
+
